HafasClient
===========
The `HafasClient` is the interface between your program and pyhafas internal code.
You need it when you're using pyHaFAS. Below you can find the API of the client.

.. automodule:: pyhafas.client
   :members:
   :undoc-members:
